@@ -32,9 +32,9 @@
   (require 'liece-compat)
   (require 'liece-vars))
 
+(eval-when-compile (require 'cl))
 (eval-when-compile (ignore-errors (require 'image)))
 
-(require 'pces)
 (require 'derived)
 
 (eval-and-compile
@@ -94,7 +94,7 @@
     (let ((file (expand-file-name "liece.xpm" default-directory)))
       (if (file-exists-p file)
 	  (with-temp-buffer
-	    (insert-file-contents-as-binary file)
+	    (insert-file-contents file)
 	    (buffer-string))))))
 
 (defun liece-emacs-splash-with-image ()
